[PATCH] help: use :hg: role and canonical name to point to revset string patterns

Yuya Nishihara yuya at tcha.org
Fri Jan 13 15:17:12 UTC 2017


# HG changeset patch
# User Yuya Nishihara <yuya at tcha.org>
# Date 1484318901 -32400
#      Fri Jan 13 23:48:21 2017 +0900
# Node ID 8696824643b77a0ca52ad284ab0409b66e5f0c9d
# Parent  33359a4d0e90d528a27cfbf831b673e7a6fdacac
help: use :hg: role and canonical name to point to revset string patterns

Follows up 5dd67f0993ce. Now revisions.txt and revsets.txt has been merged,
so use revisions.* as a pointer.

diff --git a/mercurial/revset.py b/mercurial/revset.py
--- a/mercurial/revset.py
+++ b/mercurial/revset.py
@@ -619,7 +619,7 @@ def bisected(repo, subset, x):
 def bookmark(repo, subset, x):
     """The named bookmark or all bookmarks.
 
     Pattern matching is supported for `name`. See ``hg help revsets.patterns``.
     """
     # i18n: "bookmark" is a keyword
     args = getargs(x, 0, 1, _('bookmark takes one or no arguments'))
@@ -658,7 +658,7 @@ def branch(repo, subset, x):
     changesets.
 
     Pattern matching is supported for `string`. See
-    ``hg help revsets.patterns``.
+    :hg:`help revisions.patterns`.
     """
     getbi = repo.revbranchcache().branchinfo
 
@@ -844,7 +844,7 @@ def desc(repo, subset, x):
     """Search commit message for string. The match is case-insensitive.
 
     Pattern matching is supported for `string`. See
-    ``hg help revsets.patterns``.
+    :hg:`help revisions.patterns`.
     """
     # i18n: "desc" is a keyword
     ds = getstring(x, _("desc requires a string"))
@@ -955,7 +955,7 @@ def extra(repo, subset, x):
     optional value.
 
     Pattern matching is supported for `value`. See
-    ``hg help revsets.patterns``.
+    :hg:`help revisions.patterns`.
     """
     args = getargsdict(x, 'extra', 'label value')
     if 'label' not in args:
@@ -1424,7 +1424,7 @@ def named(repo, subset, x):
     """The changesets in a given namespace.
 
     Pattern matching is supported for `namespace`. See
-    ``hg help revsets.patterns``.
+    :hg:`help revisions.patterns`.
     """
     # i18n: "named" is a keyword
     args = getargs(x, 1, 1, _('named requires a namespace argument'))
@@ -2281,7 +2281,7 @@ def tag(repo, subset, x):
     """The specified tag by name, or all tagged revisions if no name is given.
 
     Pattern matching is supported for `name`. See
-    ``hg help revsets.patterns``.
+    :hg:`help revisions.patterns`.
     """
     # i18n: "tag" is a keyword
     args = getargs(x, 0, 1, _("tag takes one or no arguments"))
@@ -2323,7 +2323,7 @@ def user(repo, subset, x):
     """User name contains string. The match is case-insensitive.
 
     Pattern matching is supported for `string`. See
-    ``hg help revsets.patterns``.
+    :hg:`help revisions.patterns`.
     """
     return author(repo, subset, x)
 
@@ -619,7 +619,7 @@ def bisected(repo, subset, x):
     """The named bookmark or all bookmarks.
 
-    Pattern matching is supported for `name`. See ``hg help revsets.patterns``.
+    Pattern matching is supported for `name`. See :hg:`help revisions.patterns`.
     """
     # i18n: "bookmark" is a keyword


More information about the Mercurial-devel mailing list